==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingStacklight.md <==
# AwsIoTThingStacklight


```text
aws-20210730/Resource/LoT/AwsIoTThingStacklight
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')
```



| Illustration | AwsIoTThingStacklight | AwsIoTThingStacklightCard | AwsIoTThingStacklightGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklight.png) | ![illustration for AwsIoTThingStacklight](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklight.Local.png) | ![illustration for AwsIoTThingStacklightCard](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklightCard.Local.png) | ![illustration for AwsIoTThingStacklightGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklightGroup.Local.png) |




## AwsIoTThingStacklight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklight
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklight('AwsIoTThingStacklight', 'Aws Io T Thing Stacklight', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklight
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklight('AwsIoTThingStacklight', 'Aws Io T Thing Stacklight', 'an optional tech label')
@enduml
```

## AwsIoTThingStacklightCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightCard
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightCard('AwsIoTThingStacklightCard', 'Aws Io T Thing Stacklight Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightCard
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightCard('AwsIoTThingStacklightCard', 'Aws Io T Thing Stacklight Card', 'an optional description')
@enduml
```

## AwsIoTThingStacklightGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightGroup
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightGroup('AwsIoTThingStacklightGroup', 'Aws Io T Thing Stacklight Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightGroup
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightGroup('AwsIoTThingStacklightGroup', 'Aws Io T Thing Stacklight Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingStacklight.md <==
# AwsIoTThingStacklight


```text
aws-20210730/Resource/LoT/AwsIoTThingStacklight
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')
```



| Illustration | AwsIoTThingStacklight | AwsIoTThingStacklightCard | AwsIoTThingStacklightGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklight.png) | ![illustration for AwsIoTThingStacklight](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklight.Local.png) | ![illustration for AwsIoTThingStacklightCard](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklightCard.Local.png) | ![illustration for AwsIoTThingStacklightGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingStacklightGroup.Local.png) |




## AwsIoTThingStacklight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklight
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklight('AwsIoTThingStacklight', 'Aws Io T Thing Stacklight', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklight
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklight('AwsIoTThingStacklight', 'Aws Io T Thing Stacklight', 'an optional tech label')
@enduml
```

## AwsIoTThingStacklightCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightCard
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightCard('AwsIoTThingStacklightCard', 'Aws Io T Thing Stacklight Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightCard
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightCard('AwsIoTThingStacklightCard', 'Aws Io T Thing Stacklight Card', 'an optional description')
@enduml
```

## AwsIoTThingStacklightGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightGroup
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightGroup('AwsIoTThingStacklightGroup', 'Aws Io T Thing Stacklight Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingStacklightGroup
include('aws-20210730/Resource/LoT/AwsIoTThingStacklight')

' renders the element
AwsIoTThingStacklightGroup('AwsIoTThingStacklightGroup', 'Aws Io T Thing Stacklight Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
